@@ -1,7 +1,10 @@
 #!/bin/bash -ex
 
 ver=$1
-[[ -z $ver ]] && exit 1
+if [[ -z $ver ]]; then
+	echo "Usage: $0 <kernel ver>"
+	exit 1
+fi
 [[ ${ver} == linux-* ]] && ver=${ver#linux-}
 ver=${ver%/}
 
@@ -9,7 +12,7 @@ src=linux-${ver}
 dst=gentoo-headers-base-${ver}
 
 if [ ! -d ${src} ] ; then
-	for srcdir in . /usr/portage/distfiles ; do
+	for srcdir in . "$(portageq distdir)" /usr/portage/distfiles ; do
 		for ext in bz2 xz ; do
 			srctar=${srcdir}/${src}.tar.${ext}
 			if [ -e ${srctar} ] ; then
@@ -28,8 +31,13 @@ rm -rf ${dst}
 mkdir ${dst}
 cp ${src}/Makefile ${dst}/
 mkdir ${dst}/include
-cp ${src}/include/Kbuild ${dst}/include/
-cp -r $(find ${src}/include -mindepth 2 -maxdepth 2 -name 'Kbuild*' -printf %h' ') ${dst}/include/
+[ -f ${src}/include/Kbuild ] && cp ${src}/include/Kbuild ${dst}/include/
+directories=$(find ${src}/include -mindepth 2 -maxdepth 2 -name 'Kbuild*' -printf %h' ')
+if [ -n "${directories}" ] ; then
+	cp -r ${directories} ${dst}/include/
+else
+	cp -r ${src}/include/* ${dst}/include
+fi
 mkdir ${dst}/scripts
 cp -r \
 	${src}/scripts/{Makefile,Kbuild}* \
